==> zio-aws-textract_2.12-5.17.116.2-sources.jar: zio/aws/textract/model/Geometry.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Geometry(
    boundingBox: Option[zio.aws.textract.model.BoundingBox] = None,
    polygon: Option[Iterable[zio.aws.textract.model.Point]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.Geometry = {
    import Geometry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.Geometry
      .builder()
      .optionallyWith(boundingBox.map(value => value.buildAwsValue()))(
        _.boundingBox
      )
      .optionallyWith(
        polygon.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.polygon)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.Geometry.ReadOnly =
    zio.aws.textract.model.Geometry.wrap(buildAwsValue())
}
object Geometry {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.textract.model.Geometry] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.Geometry =
      zio.aws.textract.model.Geometry(
        boundingBox.map(value => value.asEditable),
        polygon.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def boundingBox: Option[zio.aws.textract.model.BoundingBox.ReadOnly]
    def polygon: Option[List[zio.aws.textract.model.Point.ReadOnly]]
    def getBoundingBox
        : ZIO[Any, AwsError, zio.aws.textract.model.BoundingBox.ReadOnly] =
      AwsError.unwrapOptionField("boundingBox", boundingBox)
    def getPolygon
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Point.ReadOnly]] =
      AwsError.unwrapOptionField("polygon", polygon)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.Geometry
  ) extends zio.aws.textract.model.Geometry.ReadOnly {
    override val boundingBox
        : Option[zio.aws.textract.model.BoundingBox.ReadOnly] = scala
      .Option(impl.boundingBox())
      .map(value => zio.aws.textract.model.BoundingBox.wrap(value))
    override val polygon: Option[List[zio.aws.textract.model.Point.ReadOnly]] =
      scala
        .Option(impl.polygon())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.Point.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.Geometry
  ): zio.aws.textract.model.Geometry.ReadOnly = new Wrapper(impl)
}

==> zio-aws-textract_2.13-5.17.161.2-sources.jar: zio/aws/textract/model/Geometry.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Geometry(
    boundingBox: Optional[zio.aws.textract.model.BoundingBox] = Optional.Absent,
    polygon: Optional[Iterable[zio.aws.textract.model.Point]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.Geometry = {
    import Geometry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.Geometry
      .builder()
      .optionallyWith(boundingBox.map(value => value.buildAwsValue()))(
        _.boundingBox
      )
      .optionallyWith(
        polygon.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.polygon)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.Geometry.ReadOnly =
    zio.aws.textract.model.Geometry.wrap(buildAwsValue())
}
object Geometry {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.textract.model.Geometry] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.Geometry =
      zio.aws.textract.model.Geometry(
        boundingBox.map(value => value.asEditable),
        polygon.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def boundingBox: Optional[zio.aws.textract.model.BoundingBox.ReadOnly]
    def polygon: Optional[List[zio.aws.textract.model.Point.ReadOnly]]
    def getBoundingBox
        : ZIO[Any, AwsError, zio.aws.textract.model.BoundingBox.ReadOnly] =
      AwsError.unwrapOptionField("boundingBox", boundingBox)
    def getPolygon
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Point.ReadOnly]] =
      AwsError.unwrapOptionField("polygon", polygon)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.Geometry
  ) extends zio.aws.textract.model.Geometry.ReadOnly {
    override val boundingBox
        : Optional[zio.aws.textract.model.BoundingBox.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.boundingBox())
        .map(value => zio.aws.textract.model.BoundingBox.wrap(value))
    override val polygon
        : Optional[List[zio.aws.textract.model.Point.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.polygon())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.Point.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.Geometry
  ): zio.aws.textract.model.Geometry.ReadOnly = new Wrapper(impl)
}
